## 0.2.1 (2025-04-12)

## 0.2.0 (2025-04-12)

### Feat

- added jsonx and config

### Fix

- update cz config
- added tests for autodiscovery
- added support for autodiscovery
- removed gyver, env-star and lazyfields references
- added support for context-handler
